@@ -1,10 +1,7 @@
 from sklearn.pipeline import Pipeline
 
 # from feature-engine
-from feature_engine.imputation import (
-    MeanMedianImputer,
-    AddMissingIndicator
-)
+from feature_engine.imputation import MeanMedianImputer,AddMissingIndicator
 
 from feature_engine.encoding import OneHotEncoder
 from sklearn.linear_model import LogisticRegression
@@ -26,6 +23,8 @@ pipe = Pipeline([
             variables=config.model_config.numerical_vars_with_na,
         ),
     ),
+    ('categorical_encoder', OneHotEncoder(top_categories=1, variables=config.model_config.categorical_vars
+    )),
     ('LogisticRegression', LogisticRegression())
    
    ])
\ No newline at end of file
